aboutsummaryrefslogtreecommitdiffstats
path: root/ram
diff options
context:
space:
mode:
Diffstat (limited to 'ram')
-rw-r--r--ram/wram.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/ram/wram.asm b/ram/wram.asm
index f93d37d7..4e3e6411 100644
--- a/ram/wram.asm
+++ b/ram/wram.asm
@@ -1815,11 +1815,11 @@ wObjectDataPointerTemp:: dw
; the tile shown outside the boundaries of the map
wMapBackgroundTile:: db
; number of warps in current map (up to 32)
wNumberOfWarps:: db
; current map warp entries
-wWarpEntries:: ds 32 * 4 ; Y, X, warp ID, map ID
+wWarpEntries:: ds MAX_WARP_EVENTS * 4 ; Y, X, warp ID, map ID
; if $ff, the player's coordinates are not updated when entering the map
wDestinationWarpID:: db
@@ -1815,11 +1815,11 @@ wObjectDataPointerTemp:: dw
; the tile shown outside the boundaries of the map
wMapBackgroundTile:: db
-; number of warps in current map (up to 32)
+; number of warps in current map (up to MAX_WARP_EVENTS)
wNumberOfWarps:: db
; current map warp entries